@@ -1,4 +1,19 @@
 
+#' The igraph console
+#'
+#' @description
+#' `r lifecycle::badge("deprecated")`
+#'
+#' `igraph.console()` was renamed to `console()` to create a more
+#' consistent API.
+#'
+#' @keywords internal
+#' @export
+igraph.console <- function() { # nocov start
+  lifecycle::deprecate_soft("2.0.0", "igraph.console()", "console()")
+  console()
+} # nocov end
+
 #   IGraph R package
 #   Copyright (C) 2010-2012  Gabor Csardi <csardi.gabor@gmail.com>
 #   334 Harvard street, Cambridge, MA 02139 USA
@@ -20,10 +35,42 @@
 #
 ###################################################################
 
-.igraph.pb <- NULL
 
+#' The igraph console
+#'
+#' The igraph console is a GUI window that shows what the currently running
+#' igraph function is doing.
+#'
+#' The console can be started by calling the `console()` function.
+#' Then it stays open, until the user closes it.
+#'
+#' Another way to start it to set the `verbose` igraph option to
+#' \dQuote{tkconsole} via `igraph_options()`. Then the console (re)opens
+#' each time an igraph function supporting it starts; to close it, set the
+#' `verbose` option to another value.
+#'
+#' The console is written in Tcl/Tk and required the `tcltk` package.
+#'
+#' @return `NULL`, invisibly.
+#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
+#' @seealso [igraph_options()] and the `verbose` option.
+#' @keywords graphs
 #' @family console
 #' @export
+console <- function() {
+  oldverb <- igraph_opt("verbose")
+  igraph_options(verbose = "tkconsole")
+  pb <- .igraph.progress.tkconsole.create(oldverb)
+  assign(".igraph.pb", pb, envir = asNamespace("igraph"))
+  .igraph.progress.tkconsole.message("Console started.\n")
+  invisible()
+}
+
+.igraph.pb <- NULL
+
+#' igraph progress
+#' @param percent,message,clean Used internally by `.igraph.progress()` and `.igraph.status()`
+#' @dev
 .igraph.progress <- function(percent, message, clean = FALSE) {
   if (clean) {
     if (!is.null(.igraph.pb)) {
@@ -43,8 +90,9 @@
   }
 }
 
-#' @family console
-#' @export
+#' igraph status
+#' @inheritParams .igraph.progress
+#' @dev
 .igraph.status <- function(message) {
   type <- igraph_opt("verbose")
   if (is.logical(type) && type) {
@@ -201,6 +249,7 @@
   tcltk::tcl("update", "idletasks")
 }
 
+#' @exportS3Method NULL
 close.igraphconsole <- function(con, ...) {
   invisible()
 }
@@ -248,34 +297,3 @@ close.igraphconsole <- function(con, ...) {
   pb <- list(widget = pBar, get = get, set = set, label = .lab)
   list(frame = frame, pb = pb)
 }
-
-#' The igraph console
-#'
-#' The igraph console is a GUI windows that shows what the currently running
-#' igraph function is doing.
-#'
-#' The console can be started by calling the `console()` function.
-#' Then it stays open, until the user closes it.
-#'
-#' Another way to start it to set the `verbose` igraph option to
-#' \dQuote{tkconsole} via `igraph_options()`. Then the console (re)opens
-#' each time an igraph function supporting it starts; to close it, set the
-#' `verbose` option to another value.
-#'
-#' The console is written in Tcl/Tk and required the `tcltk` package.
-#'
-#' @aliases igraph.console
-#' @return `NULL`, invisibly.
-#' @author Gabor Csardi \email{csardi.gabor@@gmail.com}
-#' @seealso [igraph_options()] and the `verbose` option.
-#' @keywords graphs
-#' @family console
-#' @export
-console <- function() {
-  oldverb <- igraph_opt("verbose")
-  igraph_options(verbose = "tkconsole")
-  pb <- .igraph.progress.tkconsole.create(oldverb)
-  assign(".igraph.pb", pb, envir = asNamespace("igraph"))
-  .igraph.progress.tkconsole.message("Console started.\n")
-  invisible()
-}
