@@ -19,7 +19,7 @@
 #
 ###################################################################
 
-#' @family processes
+#' @rdname sir
 #' @export
 time_bins <- function(x, middle = TRUE) {
   UseMethod("time_bins")
@@ -27,7 +27,6 @@ time_bins <- function(x, middle = TRUE) {
 
 #' @method time_bins sir
 #' @rdname sir
-#' @family processes
 #' @export
 #' @importFrom stats IQR
 time_bins.sir <- function(x, middle = TRUE) {
@@ -52,7 +51,6 @@ time_bins.sir <- function(x, middle = TRUE) {
 #' @importFrom stats median
 #' @method median sir
 #' @rdname sir
-#' @family processes
 #' @export
 median.sir <- function(x, na.rm = FALSE, ...) {
   sir <- x
@@ -73,7 +71,6 @@ median.sir <- function(x, na.rm = FALSE, ...) {
 #' @importFrom stats quantile
 #' @method quantile sir
 #' @rdname sir
-#' @family processes
 #' @export
 quantile.sir <- function(x, comp = c("NI", "NS", "NR"), prob, ...) {
   sir <- x
@@ -181,12 +178,8 @@ plot.sir <- function(x, comp = c("NI", "NS", "NR"),
   quantile_color <- rep(quantile_color, length.out = length(quantiles))
 
   ns <- length(sir)
-  if (is.null(xlim)) {
-    xlim <- c(0, max(sapply(sir, function(x) max(x$times))))
-  }
-  if (is.null(ylim)) {
-    ylim <- c(0, max(sapply(sir, function(x) max(x[[comp]]))))
-  }
+  xlim <- xlim %||% c(0, max(sapply(sir, function(x) max(x$times))))
+  ylim <- ylim %||% c(0, max(sapply(sir, function(x) max(x[[comp]]))))
 
   ## Generate the plot, first with individual curves, and then
   ## adding median and quantile curves.
