@@ -73,7 +73,7 @@ test_that("basic plot test, spheres", {
 })
 
 test_that("rglplot() works", {
-  skip_if_not_installed("rgl")
+  skip_if_not_installed("rgl", "1.3.14")
 
   # https://stackoverflow.com/a/46320771/5489251
   withr::local_envvar(RGL_USE_NULL = TRUE)
