@@ -2,7 +2,7 @@ test_that("vs printing", {
   local_igraph_options(print.id = FALSE)
 
   local_rng_version("3.5.0")
-  set.seed(42)
+  withr::local_seed(42)
   g <- make_graph(~ A - A:B:C, B - A:B:C) %>%
     set_vertex_attr("color", value = "red") %>%
     set_vertex_attr("weight", value = sample(1:10, 3))
@@ -19,7 +19,7 @@ test_that("vs printing, complex attributes", {
   local_igraph_options(print.id = FALSE)
 
   local_rng_version("3.5.0")
-  set.seed(42)
+  withr::local_seed(42)
   g <- make_graph(~ A - A:B:C, B - A:B:C) %>%
     set_vertex_attr("color", value = "red") %>%
     set_vertex_attr("weight", value = sample(1:10, 3)) %>%
@@ -35,7 +35,7 @@ test_that("es printing", {
   local_igraph_options(print.id = FALSE)
 
   local_rng_version("3.5.0")
-  set.seed(42)
+  withr::local_seed(42)
   g <- make_graph(~ A - A:B:C, B - A:B:C) %>%
     set_edge_attr("color", value = "red") %>%
     set_edge_attr("weight", value = sample(1:10, 3))
@@ -50,7 +50,7 @@ test_that("es printing, complex attributes", {
   local_igraph_options(print.id = FALSE)
 
   local_rng_version("3.5.0")
-  set.seed(42)
+  withr::local_seed(42)
   g <- make_graph(~ A - A:B:C, B - A:B:C) %>%
     set_edge_attr("color", value = "red") %>%
     set_edge_attr("weight", value = sample(1:10, 3)) %>%
